@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.033-3-gcf5e48a
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.034-1-g5d730f7
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.034';
+$Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.035';
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
     'Dist::Zilla::Role::AfterBuild',
@@ -237,8 +237,9 @@ sub _check_modules
         ? join("\n    ", 'Issues found:', @$errors)
         : $errors->[0];
 
-    # just issue a warning if not being run interactively (e.g. travis)
-    if (not (-t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT))))
+    # just issue a warning if not being run interactively (e.g. |cpanm, travis)
+    if (($ENV{CONTINUOUS_INTEGRATION} and not $ENV{HARNESS_ACTIVE})
+        or not (-t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT))))
     {
         $self->log($message . "\n" . 'To remedy, do: cpanm ' . join(' ', @$stale_modules));
         return;
@@ -447,7 +448,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.034
+version 0.035
 
 =head1 SYNOPSIS
 
